@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 from fastapi import FastAPI
-from typing import Dict, Any, Type
+from typing import Dict, Any, Type, Mapping, Optional
+
+from patchwork.core.config import PublisherConfig
 from pydantic import BaseModel, root_validator
 
 from patchwork.core.typing import ClassPath
@@ -56,33 +58,15 @@ else:
         https_only: bool = True
 
 
-class PublisherConfig(BaseModel):
-    """
-    Publisher configuration
-
-    :cvar engine:
-        A path to class which is a publisher engine
-    :cvar options:
-        Optional mapping with options for publisher
-    """
-    engine: ClassPath
-    options: Dict = {}
-
-
 class JWTConfig(BaseModel):
     """
     JWT configuration
 
     :cvar secret:
         A secret key for JWT encryption
-    :cvar validity:
-        JWT token validity time in seconds
     """
     secret: str
 
-    # in seconds
-    validity: int
-
 
 class PatchworkFastAPISettings(BaseModel):
     """
@@ -127,7 +111,8 @@ class PatchworkFastAPISettings(BaseModel):
 settings: PatchworkFastAPISettings
 
 
-def register_patchwork(app: FastAPI, api_settings: PatchworkFastAPISettings):
+def register_patchwork(app: FastAPI, api_settings: Mapping):
+    api_settings = PatchworkFastAPISettings(**api_settings)
     global settings
     settings = api_settings
 
